# Bayesian network analysis of wt/PiZ mutant mice liver expression (RNA-seq) data using bnlearn
# input: n x (m+1) matrix of discretized gene expression values and treatment status (wt vs piz) for zinc transporter genes
# output: network structure and fitted Bayesian model

gse <- "GSE141593"
dir <- "./analysis/bnlearn/"
networkfile <- paste0(dir, gse, "_network")

# libraries and functions -------------------------------------------------
library(bnlearn)
library(Rgraphviz)


# load data and factor column values ----------------------------------------------------------------------
load(paste0(dir, gse, "_zn_transporter_gene_expr.RData"))
sample.id <- rownames(pizmice.counts)
pizmice.counts <- data.frame(lapply(pizmice.counts, FUN = function(x) factor(x)))


rownames(pizmice.counts) <- sample.id
rm(sample.id)

# generate structure from data --------------------------------------------

# score-based algorithm -- Hill Climbing
pzm.hc <- hc(pizmice.counts, restart = 500)
pzm.hc



bde.scores <- score(pzm.hc, data = pizmice.counts, type = "bde", by.node = TRUE)
print(paste("Network Score:", sum(bde.scores)))
print("Score by node:")
print(bde.scores)

# plot network ------------------------------------------------------------
graphviz.plot(pzm.hc, layout = "dot", highlight = list(nodes = "pizMutation", fill = "orange"), fontsize = 16, shape = "ellipse")



# write network to dot file and run dot -----------------------------------
write.dot(file = paste0(networkfile, ".dot"), graph = pzm.hc)
dot_command <- paste0("dot -Tpng ", paste0(networkfile, ".dot"), " -o ",  paste0(networkfile, ".png"))
system(dot_command)
cat("Final subnetwork graphic can be found in", paste0(networkfile, ".png"))

# estimate parameters -----------------------------------------------------
pz.mle.fit <- bn.fit(pzm.hc, data = pizmice.counts, method = "mle")
pz.mle.fit
pz.mle.fit$pizMutation


pz.bayes.fit <- bn.fit(pzm.hc, data = pizmice.counts, method = "bayes")
pz.bayes.fit
pz.bayes.fit$pizMutation
