full workflow is in an R markdown file in the project folder
# data acquisition
The dataset for this analysis comes from [GSE14193](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE141593), where we will use the 6wks wild type and PiZ mice data to perform analysis on a predetermined set of genes.

1. Read the GEO page on the dataset to determine what data they provide and in what formats.
	1. for this dataset, the raw count data from an RNA-seq experiment is available

2. Download the file `GSE141593_RAW.tar` and unpackage it; There will be one `.txt.gz` file per sample. Since we are only interested in the first 10 samples, we can delete the others. Unzip the individual text files and take a look at their format so that they will be properly read into R. 

# data preprocessing
The R package we are using for Bayesian network analysis requires a specific format for the input, so the count data will need to be processed into the correct format. The end goal of this step is a matrix of discretized values for each gene per sample, in which the rows represent the samples, and the columns are the genes plus a column for the experimental condition (wild type or PiZ).

I prefer to keep my scripts short and specific, so I choose to do the data preprocessing in a script separate from the actual analysis, especially when there are several steps of data preprocessing that are unique to that particular dataset. If you prefer to have everything in 1 script, that is okay too. 

## 1. merge samples into a single matrix
Since the counts are in separate files, we will need to read in each file in R and combine them into a single matrix based on the transcript IDs. 
- use the `list.files()` function to create a variable containing all the filenames for each sample
- use the `list()` function create an empty list variable that will contain each sample's  file contents
- use a for loop to  (1) read in each file,  (2) assign names to the columns in the data, and (3) save it in the list. The first column, which contains the transcript IDs, should all have the same name. The second column, which contains the counts for those transcripts for that particular sample, should be given a unique name that helps identify which sample it is. For example, For the first sample
- use `Reduce(function(x,y) merge(x,y, all = TRUE, by = "transcript.id"), sample.list)` to merge all of the data frames contained in `sample.list` by the transcript.id column


merge samples
gene annotation
collapsing transcript-level counts to the gene level
normalizing/scaling
discretizing
filtering for desired genes

# R script setup
libraries
skeleton -> sectioning script for each step -- makes it easier to read/ and provides intuitive understanding of the process before actually writing the code

# running bn learn
section by section
using the data to learn a structure
fitting parameters
conditional probabilities

# outputs
conditional probability table
network graphic
markov blanket

# graphing the network
dot, igraph, rgraphviz